@@ -78,16 +78,12 @@ class Seller(BusinessOrIndividualModel, Person, FinancialModel, SocialModel):
 
         if self.get_type() == self.BUSINESS_TYPE:
             setattr(
-                self,
-                "owner",
-                Person.from_dict_or_instance(owner, allow_empty=self._allow_empty),
+                self, "owner", Person.from_dict_or_instance(owner, allow_empty=True),
             )
             setattr(
                 self,
                 "business_address",
-                Address.from_dict_or_instance(
-                    business_address, allow_empty=self._allow_empty
-                ),
+                Address.from_dict_or_instance(business_address, allow_empty=True),
             )
         else:
             Person.init_custom_fields(self, **kwargs)
